#[repr(u8)]pub(crate) enum RecoveryMode {
Originator = 0,
Receiver = 1,
ThirdParty = 2,
}Expand description
Recovery authority for blocked inbound funds.
Variants
Implementations
Sourceimpl RecoveryMode
impl RecoveryMode
Sourcepub(crate) fn encode(authority: Address, msg_sender: Address) -> (Self, Address)
pub(crate) fn encode(authority: Address, msg_sender: Address) -> (Self, Address)
Encodes a configured recovery authority into a mode and stored authority value.
Sourcepub(crate) fn from(receipt: &ClaimReceiptV1, receiver: Address) -> Self
pub(crate) fn from(receipt: &ClaimReceiptV1, receiver: Address) -> Self
Resolves the recovery mode for a receipt and resolved receiver.
Returns the authorized claimer address for this mode.
Sourcepub(crate) fn policy_subject(
self,
originator: Address,
receiver: Address,
) -> Address
pub(crate) fn policy_subject( self, originator: Address, receiver: Address, ) -> Address
Returns the address of the account who has effective ownership of the blocked funds.
Sourcepub(crate) fn is_reroute(self, to: Address, receiver: Address) -> bool
pub(crate) fn is_reroute(self, to: Address, receiver: Address) -> bool
Returns whether a claim is a reroute under TIP-1028. Originator-authorized claims are always reroutes; non-originator recovery claims resume only when claiming to the receiver.
Sourcepub(crate) fn spending_account(
self,
recovery_authority: Address,
) -> Option<Address>
pub(crate) fn spending_account( self, recovery_authority: Address, ) -> Option<Address>
Returns the account charged for access-key spending limits, if any.